Unhide the broadcast intent that signals completion of the TTS language
files. This is required for bug 2022435.
Correct the javadoc where two intents were mislabelled as broadcast,
but were activity actions.
diff --git a/api/current.xml b/api/current.xml
index ffbe6e2..e629082 100644
--- a/api/current.xml
+++ b/api/current.xml
@@ -109309,6 +109309,17 @@
  visibility="public"
 >
 </field>
+<field name="ACTION_TTS_DATA_INSTALLED"
+ type="java.lang.String"
+ transient="false"
+ volatile="false"
+ value="&quot;android.speech.tts.engine.TTS_DATA_INSTALLED&quot;"
+ static="true"
+ final="true"
+ deprecated="not deprecated"
+ visibility="public"
+>
+</field>
 <field name="CHECK_VOICE_DATA_BAD_DATA"
  type="int"
  transient="false"
@@ -109375,6 +109386,17 @@
  visibility="public"
 >
 </field>
+<field name="EXTRA_TTS_DATA_INSTALLED"
+ type="java.lang.String"
+ transient="false"
+ volatile="false"
+ value="&quot;dataInstalled&quot;"
+ static="true"
+ final="true"
+ deprecated="not deprecated"
+ visibility="public"
+>
+</field>
 <field name="EXTRA_VOICE_DATA_FILES"
  type="java.lang.String"
  transient="false"
diff --git a/core/java/android/speech/tts/TextToSpeech.java b/core/java/android/speech/tts/TextToSpeech.java
index 4405a53..a6d76d6 100755
--- a/core/java/android/speech/tts/TextToSpeech.java
+++ b/core/java/android/speech/tts/TextToSpeech.java
@@ -61,7 +61,7 @@
 
 
     /**
-     * Denotes the language is available exactly as specified by the locale
+     * Denotes the language is available exactly as specified by the locale.
      */
     public static final int LANG_COUNTRY_VAR_AVAILABLE = 2;
 
@@ -176,7 +176,7 @@
 
         // intents to ask engine to install data or check its data
         /**
          * Broadcast Action: Triggers the platform Text-To-Speech engine to
          * start the activity that installs the resource files on the device
          * that are required for TTS to be operational. Since the installation
          * of the data can be interrupted or declined by the user, the application
@@ -184,18 +184,20 @@
          * and if need be, should check installation status with
          * {@link #ACTION_CHECK_TTS_DATA}.
          */
-        @SdkConstant(SdkConstantType.BROADCAST_INTENT_ACTION)
+        @SdkConstant(SdkConstantType.ACTIVITY_INTENT_ACTION)
         public static final String ACTION_INSTALL_TTS_DATA =
                 "android.speech.tts.engine.INSTALL_TTS_DATA";
 
         /**
-         * {@hide}
+         * Broadcast Action: broadcast to signal the completion of the installation of
+         * the data files used by the synthesis engine. Success or failure is indicated in the
+         * {@link #EXTRA_TTS_DATA_INSTALLED} extra.
          */
         @SdkConstant(SdkConstantType.BROADCAST_INTENT_ACTION)
         public static final String ACTION_TTS_DATA_INSTALLED =
                 "android.speech.tts.engine.TTS_DATA_INSTALLED";
         /**
-         * Broadcast Action: Starts the activity from the platform Text-To-Speech
+         * Activity Action: Starts the activity from the platform Text-To-Speech
          * engine to verify the proper installation and availability of the
          * resource files on the system. Upon completion, the activity will
          * return one of the following codes:
@@ -217,7 +219,7 @@
          *       and YYY is the 3-letter ISO country code.</li>
          * </ul>
          */
-        @SdkConstant(SdkConstantType.BROADCAST_INTENT_ACTION)
+        @SdkConstant(SdkConstantType.ACTIVITY_INTENT_ACTION)
         public static final String ACTION_CHECK_TTS_DATA =
                 "android.speech.tts.engine.CHECK_TTS_DATA";
 
@@ -241,11 +243,11 @@
 
         // extras for a TTS engine's data installation
         /**
-         * Extra information received with the {@link #ACTION_TTS_DATA_INSTALLED} intent
-         * which indicates whether the TTS data installation requested with
-         * {@link #ACTION_INSTALL_TTS_DATA} completed successfully or not. The value is
-         * {@link TextToSpeech#SUCCESS} or {@link TextToSpeech#ERROR}.
-         * {@hide}
+         * Extra information received with the {@link #ACTION_TTS_DATA_INSTALLED} intent.
+         * It indicates whether the data files for the synthesis engine were successfully
+         * installed. The installation was initiated with the  {@link #ACTION_INSTALL_TTS_DATA}
+         * intent. The possible values for this extra are
+         * {@link TextToSpeech#SUCCESS} and {@link TextToSpeech#ERROR}.
          */
         public static final String EXTRA_TTS_DATA_INSTALLED = "dataInstalled";
@@ -176,7 +176,7 @@
         // intents to ask engine to install data or check its data
         /**
-         * Broadcast Action: Triggers the platform Text-To-Speech engine to
+         * Activity Action: Triggers the platform Text-To-Speech engine to
          * start the activity that installs the resource files on the device
          * that are required for TTS to be operational. Since the installation